==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ImageTilesReadyEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImageTilesReadyEventArgsDescription } from "./ImageTilesReadyEventArgsDescription";
/**
 * @hidden
 */
export let ImageTilesReadyEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ImageTilesReadyEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ImageTilesReadyEventArgsDescriptionMetadata.a == null) {
                ImageTilesReadyEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ImageTilesReadyEventArgsDescriptionMetadata.c(ImageTilesReadyEventArgsDescriptionMetadata.a);
            }
            if (a.j(ImageTilesReadyEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ImageTilesReadyEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ImageTilesReadyEventArgsDescriptionMetadata.b(a);
            a.aa("ImageTilesReadyEventArgs", () => new ImageTilesReadyEventArgsDescription());
            a.z("ImageTilesReadyEventArgs", ImageTilesReadyEventArgsDescriptionMetadata.a);
        }
    }
    ImageTilesReadyEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ImageTilesReadyEventArgsDescriptionMetadata, 'ImageTilesReadyEventArgsDescriptionMetadata');
    ImageTilesReadyEventArgsDescriptionMetadata.a = null;
    return ImageTilesReadyEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ImageTilesReadyEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImageTilesReadyEventArgsDescription } from "./ImageTilesReadyEventArgsDescription";
/**
 * @hidden
 */
export let ImageTilesReadyEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ImageTilesReadyEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ImageTilesReadyEventArgsDescriptionMetadata.a == null) {
                ImageTilesReadyEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ImageTilesReadyEventArgsDescriptionMetadata.c(ImageTilesReadyEventArgsDescriptionMetadata.a);
            }
            if (a.k(ImageTilesReadyEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ImageTilesReadyEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ImageTilesReadyEventArgsDescriptionMetadata.b(a);
            a.ac("ImageTilesReadyEventArgs", () => new ImageTilesReadyEventArgsDescription());
            a.ab("ImageTilesReadyEventArgs", ImageTilesReadyEventArgsDescriptionMetadata.a);
        }
    }
    ImageTilesReadyEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ImageTilesReadyEventArgsDescriptionMetadata, 'ImageTilesReadyEventArgsDescriptionMetadata');
    ImageTilesReadyEventArgsDescriptionMetadata.a = null;
    return ImageTilesReadyEventArgsDescriptionMetadata;
})();
